[Python-modules-commits] [pep8] 01/03: New upstream version 1.7.1

Sylvestre Ledru sylvestre at moszumanska.debian.org
Mon Oct 30 08:36:48 UTC 2017


This is an automated email from the git hooks/post-receive script.

sylvestre pushed a commit to branch master
in repository pep8.

commit a0a41154ff3068b921332f044f70553022162aad
Author: Sylvestre Ledru <sylvestre at debian.org>
Date:   Mon Oct 30 09:20:44 2017 +0100

    New upstream version 1.7.1
---
 CHANGES.txt            |  7 +++++++
 PKG-INFO               | 14 +++++++++++---
 docs/index.rst         | 11 +++++++++++
 pep8.egg-info/PKG-INFO | 14 +++++++++++---
 pep8.py                | 18 ++++++++++++++++--
 setup.cfg              |  1 -
 setup.py               |  2 ++
 7 files changed, 58 insertions(+), 9 deletions(-)

diff --git a/CHANGES.txt b/CHANGES.txt
index 860b6ad..d35d569 100644
--- a/CHANGES.txt
+++ b/CHANGES.txt
@@ -1,6 +1,13 @@
 Changelog
 =========
 
+1.7.1 (2017-10-22)
+------------------
+
+Changes:
+
+* Prominently note via warning message that the tool is no longer released as
+  ``pep8`` and will only be fixed in the ``pycodestyle`` package
 
 1.7.0 (2016-01-12)
 ------------------
diff --git a/PKG-INFO b/PKG-INFO
index c44d679..8bb9316 100644
--- a/PKG-INFO
+++ b/PKG-INFO
@@ -1,11 +1,12 @@
 Metadata-Version: 1.1
 Name: pep8
-Version: 1.7.0
+Version: 1.7.1
 Summary: Python style guide checker
 Home-page: http://pep8.readthedocs.org/
-Author: Johann C. Rocholl
-Author-email: johann at rocholl.net
+Author: Ian Lee
+Author-email: IanLee1521 at gmail.com
 License: Expat license
+Description-Content-Type: UNKNOWN
 Description: pep8 - Python style guide checker
         =================================
         
@@ -102,6 +103,13 @@ Description: pep8 - Python style guide checker
         Changelog
         =========
         
+        1.7.1 (2017-10-22)
+        ------------------
+        
+        Changes:
+        
+        * Prominently note via warning message that the tool is no longer released as
+          ``pep8`` and will only be fixed in the ``pycodestyle`` package
         
         1.7.0 (2016-01-12)
         ------------------
diff --git a/docs/index.rst b/docs/index.rst
index 5e4a4c5..834a68d 100644
--- a/docs/index.rst
+++ b/docs/index.rst
@@ -3,6 +3,17 @@
 pep8's documentation
 ====================
 
+.. note::
+
+    This package used to be called `pep8 <https://pypi.python.org/pypi/pep8/1.7.0>`_ 
+    but was renamed to `pycodestyle <https://pypi.python.org/pypi/pycodestyle/2.2.0>`_
+    to reduce confusion. Further discussion can be found `in the issue where
+    Guido requested this
+    change <https://github.com/PyCQA/pycodestyle/issues/466>`_, or in the
+    lightning talk at PyCon 2016 by @IanLee1521:
+    `slides <https://speakerdeck.com/ianlee1521/pep8-vs-pep-8>`_
+    `video <https://youtu.be/PulzIT8KYLk?t=36m>`_.
+
 *Python style guide checker*
 
 pep8 is a tool to check your Python code against some of the style
diff --git a/pep8.egg-info/PKG-INFO b/pep8.egg-info/PKG-INFO
index c44d679..8bb9316 100644
--- a/pep8.egg-info/PKG-INFO
+++ b/pep8.egg-info/PKG-INFO
@@ -1,11 +1,12 @@
 Metadata-Version: 1.1
 Name: pep8
-Version: 1.7.0
+Version: 1.7.1
 Summary: Python style guide checker
 Home-page: http://pep8.readthedocs.org/
-Author: Johann C. Rocholl
-Author-email: johann at rocholl.net
+Author: Ian Lee
+Author-email: IanLee1521 at gmail.com
 License: Expat license
+Description-Content-Type: UNKNOWN
 Description: pep8 - Python style guide checker
         =================================
         
@@ -102,6 +103,13 @@ Description: pep8 - Python style guide checker
         Changelog
         =========
         
+        1.7.1 (2017-10-22)
+        ------------------
+        
+        Changes:
+        
+        * Prominently note via warning message that the tool is no longer released as
+          ``pep8`` and will only be fixed in the ``pycodestyle`` package
         
         1.7.0 (2016-01-12)
         ------------------
diff --git a/setup.cfg b/setup.cfg
index 8a0ad57..f715880 100644
--- a/setup.cfg
+++ b/setup.cfg
@@ -9,5 +9,4 @@ max_line_length = 79
 [egg_info]
 tag_build = 
 tag_date = 0
-tag_svn_revision = 0
 
diff --git a/setup.py b/setup.py
index 29182c6..421fe03 100644
--- a/setup.py
+++ b/setup.py
@@ -26,6 +26,8 @@ setup(
     keywords='pep8',
     author='Johann C. Rocholl',
     author_email='johann at rocholl.net',
+    maintainer='Ian Lee',
+    maintainer_email='IanLee1521 at gmail.com',
     url='http://pep8.readthedocs.org/',
     license='Expat license',
     py_modules=['pep8'],

diff --git a/pep8.py b/pep8.py
index 3c950d4..86c1d01 100755
--- a/pep8.py
+++ b/pep8.py
@@ -54,6 +54,7 @@ import time
 import inspect
 import keyword
 import tokenize
+import warnings
 from optparse import OptionParser
 from fnmatch import fnmatch
 try:
@@ -62,7 +63,7 @@ try:
 except ImportError:
     from ConfigParser import RawConfigParser
 
-__version__ = '1.7.0'
+__version__ = '1.7.1'
 
 DEFAULT_EXCLUDE = '.svn,CVS,.bzr,.hg,.git,__pycache__,.tox'
 DEFAULT_IGNORE = 'E121,E123,E126,E226,E24,E704'
@@ -2115,7 +2116,19 @@ def _parse_multi_options(options, split_token=','):
 
 
 def _main():
-    """Parse options and run checks on Python source."""
+    """Parse options and run checks on Python source.
+
+    Warn of deprecation and advise users to switch to pycodestyle.
+    """
+    warnings.warn(
+        '\n\n'
+        'pep8 has been renamed to pycodestyle (GitHub issue #466)\n'
+        'Use of the pep8 tool will be removed in a future release.\n'
+        'Please install and use `pycodestyle` instead.\n\n'
+        '$ pip install pycodestyle\n'
+        '$ pycodestyle ...\n'
+    )
+
     import signal
 
     # Handle "Broken pipe" gracefully
@@ -2147,5 +2160,6 @@ def _main():
             sys.stderr.write(str(report.total_errors) + '\n')
         sys.exit(1)
 
+
 if __name__ == '__main__':
     _main()
-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/python-modules/packages/pep8.git



More information about the Python-modules-commits mailing list